/**********
 * Copyright (c) 2003-2004 Greg Parker.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY GREG PARKER ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **********/

#define PSSH_VERSION "2004-01-20"
#define PSSH_UVERSION "2004_01_20"

#define PSSH_CREATOR 'GPss'

#define ftrEntropy 1  // entropy cache
#define ftrEntropyWarning 2  // warned about crappy RNG?
#define ftrSecurityWarning 3 // warned about pssh insecurity?

#define MainMenuBar                                        1000
#define TerminalMenuBar                                    1001

#define MenuAboutPalmSSH                                   1000
#define MenuConnect                                        1001
#define MenuHostKeys                                       1002
#define MenuDisconnect                                     1003
#define MenuClearScrollback                                1004
#define MenuCredits                                        1005
#define MenuSettings                                       1006
#define MenuPublicKeys                                     1007
#define MenuTCKeyboard                                     1007


#define NanoFontID                                         128
#define PasswordFontID                                     129
#define MediumFontID                                       130


#define MainFormID                                         1000
#define MainConnectButtonID 1001
#define MainNewButtonID 1002
#define MainDetailsButtonID 1003
#define MainConnectionTableID 1004
#define MainConnectionScrollbarID 1005

#define AboutFormID                                        1100

#define LoginFormID 1200
#define LoginFormConnectButtonID 1201
#define LoginFormCancelButtonID 1202
#define LoginFormSaveButtonID 1203
#define LoginFormHostFieldID 1204
#define LoginFormPortFieldID 1205
#define LoginFormUsernameFieldID 1206

#define TerminalFormID 1300
// 1300-1309 Controls present on all Terminal form flavors
#define TerminalCtrlButtonID 1301
#define TerminalMetaButtonID 1302
#define TerminalTextGadgetID 1303
#define TerminalHostFieldID 1304

// RArrows: Right side is arrow keys (harware keys are scolling)
// fixme unimplemented

// 1306-1329 RScroll: Right side is scrolling (hardware keys are arrow keys)
#define TerminalRScrollLineUpButtonID 1306
#define TerminalRScrollLineUpBitmapID 1307
#define TerminalRScrollLineUpSelectedBitmapID 1308
#define TerminalRScrollLineUpDisabledBitmapID 1309
#define TerminalRScrollLineDownButtonID 1310
#define TerminalRScrollLineDownBitmapID 1311
#define TerminalRScrollLineDownSelectedBitmapID 1312
#define TerminalRScrollLineDownDisabledBitmapID 1313
#define TerminalRScrollPageUpButtonID 1314
#define TerminalRScrollPageUpBitmapID 1315
#define TerminalRScrollPageUpSelectedBitmapID 1316
#define TerminalRScrollPageUpDisabledBitmapID 1317
#define TerminalRScrollPageDownButtonID 1318
#define TerminalRScrollPageDownBitmapID 1319
#define TerminalRScrollPageDownSelectedBitmapID 1320
#define TerminalRScrollPageDownDisabledBitmapID 1321

// 1330-1349 BTC: Bottom side is all 15 ASCII chars not on Tungsten C keyboard
#define TerminalBTCButtonsBitmapID 1330
// 15 self-labeled buttons
#define TerminalBTCFirstButtonID 1331
#define TerminalBTCLastButtonID 1345

// 1350-1374 BFull: Bottom side is scroll arrows and full-keyboard selectors
#define TerminalBFullABCButtonID 1350
#define TerminalBFull123ButtonID 1351
#define TerminalBFullFkeyButtonID 1352
#define TerminalBFullEtcButtonID 1353
#define TerminalBFullUpButtonID 1354
#define TerminalBFullDownButtonID 1355
#define TerminalBFullLeftButtonID 1356
#define TerminalBFullRightButtonID 1357
#define TerminalBFullUpBitmapID 1358
#define TerminalBFullDownBitmapID 1359
#define TerminalBFullLeftBitmapID 1360
#define TerminalBFullRightBitmapID 1361
#define TerminalBFullUpSelectedBitmapID 1362
#define TerminalBFullDownSelectedBitmapID 1363
#define TerminalBFullLeftSelectedBitmapID 1364
#define TerminalBFullRightSelectedBitmapID 1365

// TNone: Top side is full-size vt100
// No additional controls

// 1375-1449 TABC: Top side is QWERTY keyboard
#define TerminalTABCButtonsBitmapID 1375
// 26 self-labeled lowercase letters
#define TerminalTABCFirstAlphaButtonID 1376
#define TerminalTABCLastAlphaButtonID 1401
// 6 self-labeled punctuation
#define TerminalTABCFirstPunctButtonID 1402
#define TerminalTABCLastPunctButtonID 1407
// 26 self-labeled uppercase letters
#define TerminalTABCFirstALPHAButtonID 1408
#define TerminalTABCLastALPHAButtonID 1433
// 6 self-labeled shifted punctuation
#define TerminalTABCFirstPUNCTButtonID 1434
#define TerminalTABCLastPUNCTButtonID 1439
// 6 non-self-labeled buttons
#define TerminalTABCTabButtonID 1440
#define TerminalTABCCapsButtonID 1441
#define TerminalTABCShiftButtonID 1442
#define TerminalTABCSpaceButtonID 1443
#define TerminalTABCBackspaceButtonID 1444
#define TerminalTABCReturnButtonID 1445

// button ranges: all, lower, upper, caps (upper alpha but lower punct)
#define TerminalTABCFirstButtonID TerminalTABCFirstAlphaButtonID
#define TerminalTABCLastButtonID TerminalTABCLastPUNCTButtonID
#define TerminalTABCFirstLowercaseButtonID TerminalTABCFirstAlphaButtonID
#define TerminalTABCLastLowercaseButtonID TerminalTABCLastPunctButtonID
#define TerminalTABCFirstUppercaseButtonID TerminalTABCFirstALPHAButtonID
#define TerminalTABCLastUppercaseButtonID TerminalTABCLastPUNCTButtonID
#define TerminalTABCFirstCapscaseButtonID TerminalTABCFirstPunctButtonID
#define TerminalTABCLastCapscaseButtonID TerminalTABCLastALPHAButtonID

// 1450-1499 T123: Top side is number pad and symbols
#define TerminalT123ButtonsBitmapID 1450
// 44 self-labeled buttons
#define TerminalT123FirstButtonID 1451
#define TerminalT123LastButtonID 1494
// 4 non-self-labeled buttons
#define TerminalT123BackspaceButtonID 1495
#define TerminalT123TabButtonID 1496
#define TerminalT123ReturnButtonID 1497
#define TerminalT123SpaceButtonID 1498

// 1500-1549 TFkey: Top side is function keys (unimplemented)
// 1550-1599 TEtc: Top side is customizable keys (unimplemented)

#define PasswordFormID 1500
#define PasswordFormOKButtonID 1501
#define PasswordFormCancelButtonID 1502
#define PasswordFormHostFieldID 1503
#define PasswordFormUsernameFieldID 1504
#define PasswordFormPasswordFieldID 1505
#define PasswordFormEchoCheckboxID 1506

#define DetailsFormID 1600
#define DetailsFormOKButtonID 1601
#define DetailsFormCancelButtonID 1602
#define DetailsFormDeleteButtonID 1603
#define DetailsFormHostFieldID 1604
#define DetailsFormPortFieldID 1605
#define DetailsFormUsernameFieldID 1606

#define HostKeysFormID 1800
#define HostKeysFormOKButtonID 1801
#define HostKeysFormDetailsButtonID 1802
#define HostKeysFormKeyTableID 1803
#define HostKeysFormKeyScrollbarID 1804

#define HostKeyWarningFormID 1900
#define HostKeyWarningFormRejectButtonID 1901
#define HostKeyWarningFormTrustOnceButtonID 1902
#define HostKeyWarningFormTrustForeverButtonID 1903
#define HostKeyWarningFormContentFieldID 1904
#define HostKeyWarningFormAddressFieldID 1905

#define HostKeyDetailsFormID 2000
#define HostKeyDetailsFormOKButtonID 2001
#define HostKeyDetailsFormDeleteButtonID 2002
#define HostKeyDetailsFormHostFieldID 2003
#define HostKeyDetailsFormKeyTypeFieldID 2004
#define HostKeyDetailsFormKeyFieldID 2005
#define HostKeyDetailsFormKeyScrollbarID 2006

#define CreditsFormID 2100
#define CreditsFormFieldID 2101
#define CreditsFormScrollbarID 2102
#define CreditsFormOKButtonID 2103

#define PrefsFormID 2200
#define PrefsFormOKButtonID 2201
#define PrefsFormCancelButtonID 2202
#define PrefsFormSmallFontCheckboxID 2203
#define PrefsFormLargeFontCheckboxID 2204
#define PrefsFormXtermCheckboxID 2205
#define PrefsFormXtermColorCheckboxID 2206
#define PrefsFormVT100CheckboxID 2207
#define PrefsFormVT220CheckboxID 2208
#define PrefsFormForeColorTriggerID 2209
#define PrefsFormBackColorTriggerID 2210
#define PrefsFormForeColorListID 2211
#define PrefsFormBackColorListID 2212
#define PrefsFormSampleTextGadgetID 2213

#define MemoFormID 2300
#define MemoFormImportButtonID 2301
#define MemoFormCancelButtonID 2302
#define MemoFormTableID 2303
#define MemoFormScrollbarID 2304

#define PublicKeysFormID 2400
#define PublicKeysFormOKButtonID 2401
#define PublicKeysFormDetailsButtonID 2402
#define PublicKeysFormImportButtonID 2403
#define PublicKeysFormKeyTableID 2404
#define PublicKeysFormKeyScrollbarID 2405

#define PublicKeyDetailsFormID 2500
#define PublicKeyDetailsFormOKButtonID 2501
#define PublicKeyDetailsFormCancelButtonID 2502
#define PublicKeyDetailsFormDeleteButtonID 2503
#define PublicKeyDetailsFormCommentFieldID 2504
#define PublicKeyDetailsFormKeyTypeFieldID 2505
#define PublicKeyDetailsFormKeyFieldID 2506
#define PublicKeyDetailsFormKeyScrollbarID 2507

#define PassphraseFormID 2600
#define PassphraseFormOKButtonID 2601
#define PassphraseFormCancelButtonID 2602
#define PassphraseFormMessageFieldID 2603
#define PassphraseFormPassphraseFieldID 2604
#define PassphraseFormEchoCheckboxID 2605

#define PublicKeyChoiceFormID 2700
#define PublicKeyChoiceFormOKButtonID 2701
#define PublicKeyChoiceFormCancelButtonID 2702
#define PublicKeyChoiceFormHostFieldID 2703
#define PublicKeyChoiceFormUsernameFieldID 2704
#define PublicKeyChoiceFormPassphraseFieldID 2705
#define PublicKeyChoiceFormEchoCheckboxID 2706
#define PublicKeyChoiceFormKeyListID 2707
#define PublicKeyChoiceFormKeyTriggerID 2708


#define DeleteConnectionAlertID 6000
#define DeleteHostKeyAlertID 6100
#define AlertFormID 6200
#define FatalAlertID 6300
#define NetworkErrorAlertID 6400
#define DeletePublicKeyAlertID 6500
